@@ -1,4 +1,3 @@
-import asyncio
 import sys
 import importlib
 
@@ -11,4 +10,4 @@ entry_package_name, entry_name = entry_path.rsplit(".", 1)
 entry_package = importlib.import_module(entry_package_name)
 entry = getattr(entry_package, entry_name)
 
-asyncio.run(bot_runner(entry, *args))
+bot_runner(entry, *args)
