@@ -12,7 +12,12 @@ async def console_output(text, *args, **kwargs):
     print(f"Bot: {text}")
 
 
-async def bot_runner(bot, *args) -> None:
+async def bot_init(bot, *args, **kwargs) -> None:
     s = ConversationState(console_output)
     s.memory["user_id"] = "shelluser"
-    await asyncio.gather(input_loop(s), bot(s, *args))
+    await asyncio.gather(input_loop(s), bot(s, *args, **kwargs))
+
+
+def bot_runner(bot, *args, **kwargs):
+    loop = asyncio.get_event_loop()
+    loop.run_until_complete(bot_init(bot, *args, **kwargs))
